@@ -152,7 +152,7 @@ class DateWidget(z3c.form.browser.widget.HTMLTextInputWidget,
                 today = zope.i18n.translate(_(u"Today"), context=self.request)
             )
 
-    popup_calendar_icon = '.css("background","url(popup_calendar.gif")' \
+    popup_calendar_icon = '.css("background","url(popup_calendar.gif)")' \
                           '.css("height", "16px")' \
                           '.css("width", "16px")' \
                           '.css("display", "inline-block")' \
@@ -164,8 +164,12 @@ class DateWidget(z3c.form.browser.widget.HTMLTextInputWidget,
         localize =  'jQuery.tools.dateinput.localize("' + language + '", {'
         localize += 'months: "%s",' % ','.join(calendar.getMonthNames())
         localize += 'shortMonths: "%s",' % ','.join(calendar.getMonthAbbreviations())
-        localize += 'days: "%s",' % ','.join(calendar.getDayNames())
-        localize += 'shortDays: "%s"' % ','.join(calendar.getDayAbbreviations())
+        # calendar tool's number of days is off by one from jquery tools'
+        localize += 'days: "%s",' % ','.join(
+            [calendar.getDayNames()[6]] + calendar.getDayNames()[:6])
+        localize += 'shortDays: "%s"' % ','.join(
+            [calendar.getDayAbbreviations()[6]] +
+            calendar.getDayAbbreviations()[:6])
         localize += '});'
 
         config = 'lang: "%s", ' % language
@@ -180,23 +184,26 @@ class DateWidget(z3c.form.browser.widget.HTMLTextInputWidget,
                     'jQuery("#%(id)s-month").val(value[1]); \n' \
                     'jQuery("#%(id)s-day").val(value[2]); \n' \
                 '}, ' % dict(id = self.id)
+        config += 'firstDay: %s,' % (calendar.week['firstDay'] % 7)
         config += self.jquerytools_dateinput_config
 
         return '''
             <input type="hidden" name="%(name)s-calendar"
                    id="%(id)s-calendar" />
             <script type="text/javascript">
-                if (jQuery().dateinput) {
-                    %(localize)s
-                    jQuery("#%(id)s-calendar").dateinput({%(config)s}).unbind('change')
-                        .bind('onShow', function (event) {
-                            var trigger_offset = jQuery(this).next().offset();
-                            jQuery(this).data('dateinput').getCalendar().offset(
-                                {top: trigger_offset.top+20, left: trigger_offset.left}
-                            );
-                        });
-                    jQuery("#%(id)s-calendar").next()%(popup_calendar_icon)s;
-                }
+                jQuery(document).ready(function() {
+                    if (jQuery().dateinput) {
+                        %(localize)s
+                        jQuery("#%(id)s-calendar").dateinput({%(config)s}).unbind('change')
+                            .bind('onShow', function (event) {
+                                var trigger_offset = jQuery(this).next().offset();
+                                jQuery(this).data('dateinput').getCalendar().offset(
+                                    {top: trigger_offset.top+20, left: trigger_offset.left}
+                                );
+                            });
+                        jQuery("#%(id)s-calendar").next()%(popup_calendar_icon)s;
+                    }
+                });
             </script>''' % dict(
                 id=self.id, name=self.name,
                 day=self.day, month=self.month, year=self.year,
